@@ -533,6 +533,29 @@ class ForceDeleteDatabaseInstance(command.Command):
             raise exceptions.CommandError(msg)
 
 
+class PromoteDatabaseInstanceToReplicaSource(command.Command):
+
+    _description = _(
+        "Promotes a replica to be the new replica source of its set.")
+
+    def get_parser(self, prog_name):
+        parser = super(PromoteDatabaseInstanceToReplicaSource,
+                       self).get_parser(prog_name)
+        parser.add_argument(
+            'instance',
+            metavar='<instance>',
+            type=str,
+            help=_('ID or name of the instance.'),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        db_instances = self.app.client_manager.database.instances
+        instance = osc_utils.find_resource(db_instances,
+                                           parsed_args.instance)
+        db_instances.promote_to_replica_source(instance)
+
+
 class RestartDatabaseInstance(command.Command):
 
     _description = _("Restarts an instance.")
@@ -556,6 +579,28 @@ class RestartDatabaseInstance(command.Command):
         db_instances.restart(instance)
 
 
+class EjectDatabaseInstanceReplicaSource(command.Command):
+
+    _description = _("Ejects a replica source from its set.")
+
+    def get_parser(self, prog_name):
+        parser = super(EjectDatabaseInstanceReplicaSource, self).get_parser(
+            prog_name)
+        parser.add_argument(
+            'instance',
+            metavar='<instance>',
+            type=str,
+            help=_('ID or name of the instance.'),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        db_instances = self.app.client_manager.database.instances
+        instance = osc_utils.find_resource(db_instances,
+                                           parsed_args.instance)
+        db_instances.eject_replica_source(instance)
+
+
 class UpdateDatabaseInstance(command.Command):
 
     _description = _("Updates an instance: Edits name, "
@@ -610,3 +655,26 @@ class UpdateDatabaseInstance(command.Command):
                           parsed_args.name,
                           parsed_args.detach_replica_source,
                           parsed_args.remove_configuration)
+
+
+class DetachDatabaseInstanceReplica(command.Command):
+
+    _description = _("Detaches a replica instance "
+                     "from its replication source.")
+
+    def get_parser(self, prog_name):
+        parser = super(DetachDatabaseInstanceReplica, self).get_parser(
+            prog_name)
+        parser.add_argument(
+            'instance',
+            metavar='<instance>',
+            type=str,
+            help=_('ID or name of the instance.'),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        db_instances = self.app.client_manager.database.instances
+        instance = osc_utils.find_resource(db_instances,
+                                           parsed_args.instance)
+        db_instances.edit(instance, detach_replica_source=True)
