@@ -384,6 +384,45 @@ class FakeHTTPClient(base_client.HTTPClient):
             "datastore": {"version": "7.1", "type": "vertica"},
             "id": "cls-1234"}})
 
+    def get_cluster_instance_modules(self, **kw):
+        return (200, {}, {
+            "modules": [
+                {
+                    "auto_apply": False,
+                    "contents": None,
+                    "created": "2018-04-17 05:34:02.84",
+                    "datastore": "mariadb",
+                    "datastore_version": "all",
+                    "id": "module-1",
+                    "is_admin": False,
+                    "md5": "md5-1",
+                    "message": "Module.V1",
+                    "name": "mymod1",
+                    "removed": None,
+                    "status": "OK",
+                    "tenant": "7f1f041fc291455b83a0b3eb98140808",
+                    "type": "ping",
+                    "updated": "2018-04-17 05:34:02.84",
+                    "visible": True},
+
+                {
+                    "auto_apply": False,
+                    "contents": None,
+                    "created": "2018-04-17 05:34:02.84",
+                    "datastore": "mariadb",
+                    "datastore_version": "all",
+                    "id": "module-2",
+                    "is_admin": False,
+                    "md5": "md5-2",
+                    "message": "Module.V1",
+                    "name": "mymod2",
+                    "removed": None,
+                    "status": "OK",
+                    "tenant": "7f1f041fc291455b83a0b3eb98140808",
+                    "type": "ping",
+                    "updated": "2018-04-17 05:34:02.84",
+                    "visible": True}]})
+
     def delete_instances_1234(self, **kw):
         return (202, {}, None)
 
@@ -488,7 +527,13 @@ class FakeHTTPClient(base_client.HTTPClient):
         return (200, {}, r)
 
     def get_configurations_c_123_instances(self, **kw):
-        return (200, {}, {"instances": []})
+        return (200, {}, {"instances": [
+            {
+                "id": "1",
+                "name": "instance-1"},
+            {
+                "id": "2",
+                "name": "instance-2"}]})
 
     def delete_configurations_c_123(self, **kw):
         return (202, {}, None)
@@ -783,3 +828,25 @@ class FakeHTTPClient(base_client.HTTPClient):
 
     def update_instances_quota(self, **kw):
         return (200, {}, {"quotas": {"instances": 51}})
+
+    def get_logs(self, **kw):
+        return (200, {}, {"logs": [
+            {
+                "name": "general",
+                "type": "USER",
+                "status": "Partial",
+                "published": "128",
+                "pending": "4096",
+                "container": "data_logs",
+                "prefix": "mysql-general",
+                "metafile": "mysql-general_metafile"
+            },
+            {
+                "name": "slow_query",
+                "type": "USER",
+                "status": "Ready",
+                "published": "0",
+                "pending": "128",
+                "container": "None",
+                "prefix": "None",
+                "metafile": "mysql-slow_query_metafile"}]})
