@@ -293,3 +293,61 @@ class TestConfigurationDetach(TestConfigurations):
         result = self.cmd.take_action(parsed_args)
         self.instance_client.modify.assert_called_with('instance2')
         self.assertIsNone(result)
+
+
+class TestConfigurationInstancesList(TestConfigurations):
+    defaults = {
+        'limit': None,
+        'marker': None
+    }
+
+    columns = (
+        database_configurations.ListDatabaseConfigurationInstances.columns)
+    values = [('1', 'instance-1'),
+              ('2', 'instance-2')]
+
+    def setUp(self):
+        super(TestConfigurationInstancesList, self).setUp()
+        self.cmd = database_configurations.ListDatabaseConfigurationInstances(
+            self.app, None)
+        data = (
+            self.fake_configurations.get_configuration_instances())
+        self.configuration_client.instances.return_value = common.Paginated(
+            data)
+
+    @mock.patch.object(utils, 'find_resource')
+    def test_configuration_instances_list(self, mock_find):
+        args = ['c-123']
+        mock_find.return_value = args[0]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        columns, data = self.cmd.take_action(parsed_args)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.values, data)
+
+
+class TestConfigurationDefault(TestConfigurations):
+
+    values = ('2', '98', '1', '15M')
+
+    def setUp(self):
+        super(TestConfigurationDefault, self).setUp()
+        self.cmd = database_configurations.DefaultDatabaseConfiguration(
+            self.app, None)
+        self.data = (
+            self.fake_configurations.get_default_configuration())
+        self.instance_client.configuration.return_value = self.data
+        self.columns = (
+            'innodb_log_files_in_group',
+            'max_user_connections',
+            'skip-external-locking',
+            'tmp_table_size',
+        )
+
+    @mock.patch.object(utils, 'find_resource')
+    def test_default_database_configuration(self, mock_find):
+        args = ['1234']
+        mock_find.return_value = args[0]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        columns, data = self.cmd.take_action(parsed_args)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.values, data)
