@@ -284,6 +284,24 @@ class TestDatabaseInstanceEnableLog(TestInstances):
                                                            'log_name')
 
 
+class TestDatabaseInstancePromoteToReplicaSource(TestInstances):
+
+    def setUp(self):
+        super(TestDatabaseInstancePromoteToReplicaSource, self).setUp()
+        self.cmd = database_instances.PromoteDatabaseInstanceToReplicaSource(
+            self.app, None)
+
+    @mock.patch.object(utils, 'find_resource')
+    def test_instance_promote_to_replica_source(self, mock_find):
+        args = ['instance']
+        mock_find.return_value = args[0]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        result = self.cmd.take_action(parsed_args)
+        self.instance_client.promote_to_replica_source.assert_called_with(
+            'instance')
+        self.assertIsNone(result)
+
+
 class TestDatabaseInstanceRestart(TestInstances):
 
     def setUp(self):
@@ -299,3 +317,61 @@ class TestDatabaseInstanceRestart(TestInstances):
         result = self.cmd.take_action(parsed_args)
         self.instance_client.restart.assert_called_with('instance1')
         self.assertIsNone(result)
+
+
+class TestDatabaseInstanceEjectReplicaSource(TestInstances):
+
+    def setUp(self):
+        super(TestDatabaseInstanceEjectReplicaSource, self).setUp()
+        self.cmd = database_instances.EjectDatabaseInstanceReplicaSource(
+            self.app, None)
+
+    @mock.patch.object(utils, 'find_resource')
+    def test_eject_replica_source(self, mock_find):
+        args = ['instance']
+        mock_find.return_value = args[0]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        result = self.cmd.take_action(parsed_args)
+        self.instance_client.eject_replica_source.assert_called_with(
+            'instance')
+        self.assertIsNone(result)
+
+
+class TestDatabaseInstanceUpdate(TestInstances):
+
+    def setUp(self):
+        super(TestDatabaseInstanceUpdate, self).setUp()
+        self.cmd = database_instances.UpdateDatabaseInstance(self.app, None)
+
+    @mock.patch.object(utils, 'find_resource')
+    def test_instance_update(self, mock_find):
+        args = ['instance1',
+                '--name', 'new_instance_name',
+                '--detach_replica_source',
+                '--remove_configuration']
+        mock_find.return_value = args[0]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        result = self.cmd.take_action(parsed_args)
+        self.instance_client.edit.assert_called_with('instance1',
+                                                     None,
+                                                     'new_instance_name',
+                                                     True, True)
+        self.assertIsNone(result)
+
+
+class TestInstanceReplicaDetach(TestInstances):
+
+    def setUp(self):
+        super(TestInstanceReplicaDetach, self).setUp()
+        self.cmd = database_instances.DetachDatabaseInstanceReplica(
+            self.app, None)
+
+    @mock.patch.object(utils, 'find_resource')
+    def test_instance_replica_detach(self, mock_find):
+        args = ['instance']
+        mock_find.return_value = args[0]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        result = self.cmd.take_action(parsed_args)
+        self.instance_client.edit.assert_called_with(
+            'instance', detach_replica_source=True)
+        self.assertIsNone(result)
