@@ -22,9 +22,9 @@ import mock
 import requests
 import testtools
 
+from troveclient.apiclient import client
 from troveclient import client as other_client
 from troveclient import exceptions
-from troveclient.openstack.common.apiclient import client
 from troveclient import service_catalog
 import troveclient.v1.client
 
@@ -44,7 +44,7 @@ class ClientTest(testtools.TestCase):
                           '0', version_map)
 
     def test_client_with_auth_system_without_auth_plugin(self):
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.AuthSystemNotFound, "AuthSystemNotFound: 'something'",
             other_client.HTTPClient, user='user', password='password',
             projectid='project', timeout=2, auth_url="http://www.blah.com",
@@ -147,7 +147,7 @@ class ClientTest(testtools.TestCase):
         mock_request.side_effect = requests.exceptions.ConnectionError(
             'connection refused')
         with mock.patch('requests.request', mock_request):
-            self.assertRaisesRegexp(
+            self.assertRaisesRegex(
                 exceptions.ClientException,
                 'Unable to establish connection: connection refused',
                 instance.get, '/instances')
@@ -376,7 +376,7 @@ class ClientTest(testtools.TestCase):
             called_args, called_kwargs = mock_request.call_args
             self.assertEqual(('POST', 'http://www.blah.com/v2.0/tokens'),
                              called_args)
-            self.assertDictEqual(headers, called_kwargs['headers'])
+            self.assertEqual(headers, called_kwargs['headers'])
 
     def test_client_get(self):
         auth_url = 'http://www.blah.com'
