@@ -13,13 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-try:
-    # handle py34
-    import builtins
-except ImportError:
-    # and py27
-    import __builtin__ as builtins
-
 import base64
 import fixtures
 import mock
@@ -230,7 +223,7 @@ class ShellTest(utils.TestCase):
         cmd = 'flavor-list --datastore_type mysql'
         exepcted_error_msg = ('Missing argument\(s\): '
                               'datastore_type, datastore_version_id')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.MissingArgs, exepcted_error_msg, self.run_command,
             cmd)
 
@@ -265,7 +258,7 @@ class ShellTest(utils.TestCase):
         cmd = 'volume-type-list --datastore_type mysql'
         exepcted_error_msg = ('Missing argument\(s\): '
                               'datastore_type, datastore_version_id')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.MissingArgs, exepcted_error_msg, self.run_command,
             cmd)
 
@@ -397,7 +390,7 @@ class ShellTest(utils.TestCase):
     def test_boot_locality_error(self):
         cmd = ('create slave-1 1 --size 1 --locality=affinity '
                '--replica_of=master_1')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.ValidationError,
             'Cannot specify locality when adding replicas to existing '
             'master.',
@@ -406,7 +399,7 @@ class ShellTest(utils.TestCase):
     def test_boot_nic_error(self):
         cmd = ('create test-member-1 1 --size 1 --volume_type lvm '
                '--nic net-id=some-id,port-id=some-id')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.ValidationError,
             'Invalid NIC argument: nic=\'net-id=some-id,port-id=some-id\'',
             self.run_command, cmd)
@@ -481,7 +474,7 @@ class ShellTest(utils.TestCase):
     def test_cluster_create_error(self):
         cmd = ('cluster-create test-clstr vertica 7.1 --instance volume=2 '
                '--instance flavor=2,volume=1')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.MissingArgs, "Missing option 'flavor'",
             self.run_command, cmd)
 
@@ -523,6 +516,50 @@ class ShellTest(utils.TestCase):
                 'name': 'test-clstr2',
                 'locality': 'affinity'}})
 
+    def test_cluster_create_with_configuration(self):
+        cmd = ('cluster-create test-clstr2 redis 3.0 '
+               '--configuration=config01 '
+               '--instance flavor=2,volume=1 '
+               '--instance flavor=02,volume=1 '
+               '--instance flavor=2,volume=1 ')
+        self.run_command(cmd)
+        self.assert_called_anytime(
+            'POST', '/clusters',
+            {'cluster': {
+                'instances': [
+                    {'flavorRef': '2',
+                     'volume': {'size': '1'}},
+                    {'flavorRef': '02',
+                     'volume': {'size': '1'}},
+                    {'flavorRef': '2',
+                     'volume': {'size': '1'}},
+                ],
+                'datastore': {'version': '3.0', 'type': 'redis'},
+                'name': 'test-clstr2',
+                'configuration': 'config01'}})
+
+    def test_cluster_create_with_extended_properties(self):
+        cmd = ('cluster-create test-clstr3 mongodb 4.0 '
+               '--instance flavor=2,volume=1 '
+               '--instance flavor=02,volume=1 '
+               '--instance flavor=2,volume=1 '
+               '--extended_properties num_mongos=3')
+        self.run_command(cmd)
+        self.assert_called_anytime(
+            'POST', '/clusters',
+            {'cluster': {
+                'instances': [
+                    {'flavorRef': '2',
+                     'volume': {'size': '1'}},
+                    {'flavorRef': '02',
+                     'volume': {'size': '1'}},
+                    {'flavorRef': '2',
+                     'volume': {'size': '1'}},
+                ],
+                'datastore': {'version': '4.0', 'type': 'mongodb'},
+                'name': 'test-clstr3',
+                'extended_properties': {'num_mongos': '3'}}})
+
     def test_cluster_create_with_nic_az(self):
         cmd = ('cluster-create test-clstr1 vertica 7.1 '
                '--instance flavor=2,volume=2,nic=\'net-id=some-id\','
@@ -555,7 +592,7 @@ class ShellTest(utils.TestCase):
                'port-id=some-port-id,availability_zone=2 '
                '--instance flavor=2,volume=1,nic=net-id=some-id,'
                'port-id=some-port-id,availability_zone=2')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.ValidationError, "Invalid 'nic' option. "
             "The value must be quoted.",
             self.run_command, cmd)
@@ -566,7 +603,7 @@ class ShellTest(utils.TestCase):
                'availability_zone=2 '
                '--instance flavor=2,volume=1,nic=\'v4-fixed-ip=10.0.0.1\','
                'availability_zone=2')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.ValidationError, 'Invalid NIC argument',
             self.run_command, cmd)
 
@@ -589,9 +626,9 @@ class ShellTest(utils.TestCase):
     def test_datastore_version_show_error(self):
         expected_error_msg = ('The datastore name or id is required to '
                               'retrieve a datastore version by name.')
-        self.assertRaisesRegexp(exceptions.NoUniqueMatch, expected_error_msg,
-                                self.run_command,
-                                'datastore-version-show v-56')
+        self.assertRaisesRegex(exceptions.NoUniqueMatch, expected_error_msg,
+                               self.run_command,
+                               'datastore-version-show v-56')
 
     def test_configuration_list(self):
         self.run_command('configuration-list')
@@ -623,7 +660,7 @@ class ShellTest(utils.TestCase):
         expected_error_msg = ('The datastore name or id is required to '
                               'retrieve the parameters for the configuration '
                               'group by name')
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             exceptions.NoUniqueMatch, expected_error_msg,
             self.run_command, 'configuration-parameter-list v-156')
 
@@ -699,7 +736,7 @@ class ShellTest(utils.TestCase):
         self.assert_called('GET', '/modules/4321')
 
     def test_module_create(self):
-        with mock.patch.object(builtins, 'open'):
+        with mock.patch('argparse.open'):
             return_value = b'mycontents'
             expected_contents = str(return_value.decode('utf-8'))
             mock_encode = mock.Mock(return_value=return_value)
@@ -787,7 +824,7 @@ class ShellTest(utils.TestCase):
     def test_module_retrieve(self):
         with mock.patch.object(troveclient.v1.modules.Module, '__getattr__',
                                mock.Mock(return_value='4321')):
-            with mock.patch.object(builtins, 'open'):
+            with mock.patch('troveclient.v1.instances.open'):
                 self.run_command('module-retrieve 1234')
                 self.assert_called(
                     'GET',
