@@ -41,6 +41,17 @@ NIC_ERROR = _("Invalid NIC argument: %s. Must specify either net-id or port-id"
 NO_LOG_FOUND_ERROR = _("ERROR: No published '%(log_name)s' log was found for "
                        "%(instance)s.")
 LOCALITY_DOMAIN = ['affinity', 'anti-affinity']
+EXT_PROPS_METAVAR = INSTANCE_METAVAR
+EXT_PROPS_HELP = _("Add extended properties for cluster create. "
+                   "Currently only support MongoDB options, other databases "
+                   "will be added in the future. "
+                   "MongoDB: "
+                   "  num_configsvr=<number_of_configsvr>, "
+                   "  num_mongos=<number_of_mongos>, "
+                   "  configsvr_volume_size=<disk_size_in_GB>, "
+                   "  configsvr_volume_type=<volume_type>, "
+                   "  mongos_volume_size=<disk_size_in_GB>, "
+                   "  mongos_volume_type=<volume_type>.")
 
 try:
     import simplejson as json
@@ -49,7 +60,7 @@ except ImportError:
 
 from troveclient import exceptions
 from troveclient import utils
-from troveclient.v1.modules import Module
+from troveclient.v1 import modules
 
 
 def _poll_for_status(poll_fn, obj_id, action, final_ok_states,
@@ -860,6 +871,11 @@ def _parse_instance_options(cs, instance_options, for_grow=False):
     return instances
 
 
+def _parse_extended_properties(extended_properties):
+    return dict([(k, v) for (k, v) in [kv.strip().split("=")
+                for kv in extended_properties.split(",")]])
+
+
 @utils.arg('name',
            metavar='<name>',
            type=str,
@@ -879,15 +895,30 @@ def _parse_instance_options(cs, instance_options, for_grow=False):
            choices=LOCALITY_DOMAIN,
            help=_('Locality policy to use when creating cluster. Choose '
                   'one of %(choices)s.'))
+@utils.arg('--extended_properties',
+           metavar=EXT_PROPS_METAVAR,
+           default=None,
+           help=EXT_PROPS_HELP)
+@utils.arg('--configuration',
+           metavar='<configuration>',
+           type=str,
+           default=None,
+           help=_('ID of the configuration group to attach to the cluster.'))
 @utils.service_type('database')
 def do_cluster_create(cs, args):
     """Creates a new cluster."""
     instances = _parse_instance_options(cs, args.instances)
+    extended_properties = {}
+    if args.extended_properties:
+        extended_properties = _parse_extended_properties(
+            args.extended_properties)
     cluster = cs.clusters.create(args.name,
                                  args.datastore,
                                  args.datastore_version,
                                  instances=instances,
-                                 locality=args.locality)
+                                 locality=args.locality,
+                                 extended_properties=extended_properties,
+                                 configuration=args.configuration)
     _print_cluster(cluster)
 
 
@@ -1780,13 +1811,13 @@ def do_metadata_delete(cs, args):
 @utils.arg('--datastore', metavar='<datastore>',
            help=_("Name or ID of datastore to list modules for. Use '%s' "
                   "to list modules that apply to all datastores.")
-           % Module.ALL_KEYWORD)
+           % modules.Module.ALL_KEYWORD)
 @utils.service_type('database')
 def do_module_list(cs, args):
     """Lists the modules available."""
     datastore = None
     if args.datastore:
-        if args.datastore.lower() == Module.ALL_KEYWORD:
+        if args.datastore.lower() == modules.Module.ALL_KEYWORD:
             datastore = args.datastore.lower()
         else:
             datastore = _find_datastore(cs, args.datastore)
